#
# spec file for package perl-JSON-MaybeXS
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name JSON-MaybeXS
Name:           perl-JSON-MaybeXS
Version:        1.004005
Release:        1.4
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Use Cpanel::JSON::XS with a fallback to JSON::XS and JSON::PP
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Cpanel::JSON::XS) >= 2.3310
BuildRequires:  perl(JSON::PP) >= 2.27300
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Needs) >= 0.002006
Requires:       perl(Cpanel::JSON::XS) >= 2.3310
Requires:       perl(JSON::PP) >= 2.27300
Recommends:     perl(Cpanel::JSON::XS) >= 2.3310
%{perl_requires}

%description
This module first checks to see if either Cpanel::JSON::XS or JSON::XS (at
at least version 3.0) is already loaded, in which case it uses that module.
Otherwise it tries to load Cpanel::JSON::XS, then JSON::XS, then JSON::PP
in order, and either uses the first module it finds or throws an error.

It then exports the 'encode_json' and 'decode_json' functions from the
loaded module, along with a 'JSON' constant that returns the class name for
calling 'new' on.

If you're writing fresh code rather than replacing JSON.pm usage, you might
want to pass options as constructor args rather than calling mutators, so
we provide our own 'new' method that supports that.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Mon May  1 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.004005
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.004005 - 2023-04-30
  - to_json and from_json are now documented (Dan Book, PR #2)
* Tue Sep 27 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.004004
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.004004 - 2022-09-17
  - slight speed optimization for is_bool()
* Sat Nov 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.004003
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.004003 - 2020-11-13
  - fix another test that fails when JSON::XS is installed, but below version 3.0
* Mon May 18 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.004002
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.004002 - 2020-05-17
  - fix test that fails when JSON::XS is installed, but below version 3.0
    (RT#132578)
* Sat May  2 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.004001
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.004001 - 2020-05-01
  - document when is_bool became available
  - now favouring Cpanel::JSON::XS over JSON::XS in more situations (the former
    is always added to prereqs when a compiler is available, although JSON::XS
    is still used at runtime if new enough and Cpanel::JSON::XS is not
    installed). This makes boolean handling more predictable and consistent.
* Fri Apr 20 2018 coolo@suse.com
- updated to 1.004000
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.004000 - 2018-04-19
  - added true and false subs so they can be used via JSON::MaybeXS rather than
    only JSON() exported sub.
* Wed Feb  7 2018 coolo@suse.com
- updated to 1.003010
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.003010 - 2018-01-28
  - use bundled ExtUtils::HasCompiler rather than ExtUtils::CBuilder to detect
    compiler availability.
  - clarify exported JSON in documentation
* Tue Feb 28 2017 coolo@suse.com
- updated to 1.003009
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.003009 - 2017-02-27
  - fix tests to no longer rely on . being in @INC (RT#120404)
* Tue Oct  4 2016 coolo@suse.com
- updated to 1.003008
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.003008 - 2016-10-03
  - added an INSTALLATION section to documentation, to clarify the use of
    dynamic prerequisites in Makefile.PL
  - minimize prereqs listed in META.json to avoid giving the appearance of XS
    prerequisites, and confusing static inspection tools such as metacpan.org.
* Tue Sep 13 2016 coolo@suse.com
- updated to 1.003007
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
* Mon Sep 12 2016 coolo@suse.com
- updated to 1.003007
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
  1.003007 - 2016-09-11
  - no changes since 1.003006_001
  1.003006_001 - 2016-06-28
  - bump prereq on JSON::PP, to ensure we get the fix for parsing utf8-encoded
    values
  - we now always upgrade JSON::XS if it is installed and below version 3.0,
    due to changes in handling booleans
  - remove test dependency on Test::Without::Module (RT#115394)
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.003005
  see /usr/share/doc/packages/perl-JSON-MaybeXS/Changes
* Mon Feb 24 2014 coolo@suse.com
- initial package 1.001000
  * created by cpanspec 1.78.07
